@@ -1,4 +1,4 @@
-# Copyright (c) 2019 - 2022, Adrian Dusa
+# Copyright (c) 2019 - 2023, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -58,6 +58,9 @@
     if (is.factor(x)) {
         x <- as.character(x)
     }
+    irv <- c(194, 160)
+    multibyte_space <- rawToChar(as.raw(irv))
+    x <- gsub(multibyte_space, " ", x)
     multibyte <- grepl("[^!-~ ]", x)
     if (any(multibyte)) {
         isna[multibyte] <- TRUE
