@@ -1,4 +1,4 @@
-# Copyright (c) 2019 - 2022, Adrian Dusa
+# Copyright (c) 2019 - 2023, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -343,5 +343,5 @@
         z[[i]] <- strsplit(gsub("[[:alnum:]]", "", x[i]), "+")[[1]]
     }
     z <- notilde(unique(unlist(z)))
-    return(z[-which(z == "")])
+    return(z[nzchar(z)])
 }
