@@ -1,4 +1,4 @@
-# Copyright (c) 2019 - 2022, Adrian Dusa
+# Copyright (c) 2019 - 2023, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -34,10 +34,7 @@
     isna <- is.na(x)
     result[isna] <- NA
     if (all(isna) || is.logical(x)) {
-        if (each) {
-            return(result)
-        }
-        return(FALSE)
+        return(result)
     }
     x <- asNumeric(x)
     isnax <- is.na(x)
